;; Generated package description from popup.el  -*- no-byte-compile: t -*-
(define-package "popup" "0.5.9.0.20251231.162233" "Visual Popup User Interface" '((emacs "24.3")) :commit "45a0b759076ce4139aba36dde0a2904136282e73" :authors '(("Tomohiro Matsuyama" . "m2ym.pub@gmail.com")) :maintainer '("Jen-Chieh" . "jcs090218@gmail.com") :keywords '("lisp") :url "https://github.com/auto-complete/popup-el")
